import {createUseOne, mapToString} from 'api/buildApiHook';
import {pipe, getProp, maybeToAsync, Async, pick, map, mapProps} from 'crocks';
import raw from 'raw.macro';


export const useCompany = createUseOne({
    getGraphQl: raw('./graphql/GetOneByPk.graphql'),
    createGraphQl: raw('./graphql/Create.graphql'),
    updateGraphQl: raw('./graphql/UpdateOneByPk.graphql'),
    deleteGraphQl: raw('./graphql/DeleteOneByPk.graphql'),
    mapFromApiUsingAuth: true,
    asyncMapFromApi: auth => pipe(
        maybeToAsync('company_by_pk prop was expected', getProp('company_by_pk')),
        map(mapProps({
            cid: mapToString,
            name: mapToString,
        })),
    ),
    asyncMapToApi: pipe(
        pick([
            'id',
            'cid',
            'name',
            'archived_at',
        ]),
        Async.Resolved
    ),
});
