import SidebarLayout from 'layout/SideBarLayout'
import Header from 'components/atom/Header';
import Breadcrumbs from 'components/Breadcrumbs';
import {NavLink, useNavigate, useParams} from 'react-router-dom';
import {useTranslation} from 'react-i18next';
import {getProp, safe, Maybe, identity, isFunction} from 'crocks'
import CompanyOrdersEditForm from '../form/CompanyOrdersEditForm';
import {useCompanyOrder} from '../api/useCompanyOrder';
import {hasLength} from '@s-e/frontend/pred';
import Nullable from 'components/atom/Nullable';
import Button from 'components/Button';
import {useRef} from 'react';
import {CompanyOrdersListRoute} from '../routes';

function CompanyOrdersEditLayot() {
    const nav = useNavigate();
    const saveRef = useRef(identity);
    const removeRef = useRef(identity);
    const {id} = useParams();
    const {data} = useCompanyOrder({id});
    const {t} = useTranslation('companyOrder', {keyPrefix: 'edit'});
    const {t: tglobal} = useTranslation();

    const breadcrumb = (
        getProp('name', data)
        .chain(safe(hasLength))
        .alt(getProp('id', data).chain(safe(hasLength)))
        .alt(Maybe.Just(t('new')))
        .option(null)
    );

    const send = () => {isFunction(saveRef.current) && saveRef.current();};

    const remove = () => { 
        if (!confirm('Are you sure you want to archive?')) return;
        
        isFunction(removeRef.current) && removeRef.current({
            id,
            archived_at: new Date()
        });
    }

    return (
        <SidebarLayout>
            <Header>
                <>
                    <Breadcrumbs>
                        <Breadcrumbs.Item>
                            <NavLink to={CompanyOrdersListRoute.props.path}>
                                {tglobal(CompanyOrdersListRoute.props.translationKey, {ns: CompanyOrdersListRoute.props.translationNs})}
                            </NavLink>
                        </Breadcrumbs.Item>
                        <Nullable on={breadcrumb}>
                            <Breadcrumbs.Item hideSlash>
                                <span className='font-semibold'>{breadcrumb}</span>
                            </Breadcrumbs.Item>
                        </Nullable>
                    </Breadcrumbs>
                    <div className='space-x-4'>
                        <Button.Nd onClick={() => nav(CompanyOrdersListRoute.props.path)}>{t`cancel`}</Button.Nd>
                        <Button onClick={send}>{t`save`}</Button>
                    </div>
                </>
            </Header>

            <div className='p-8 flex-1 flex-grow h-max'>
                <CompanyOrdersEditForm saveRef={saveRef} removeRef={removeRef} />
            </div>

            <Nullable on={id}>
                <section className={'flex p-6 print:hidden'}>
                    <Button.NoBg onClick={remove} className={'bg-red-500 text-white w-min'}>{t`archive`}</Button.NoBg>
                </section>
            </Nullable>

        </SidebarLayout>
    )
}

export default CompanyOrdersEditLayot
